@@ -1002,7 +1002,8 @@ class NumerousAdminClient(NumerousClient):
     def update_execution(self, update_):
         self._base_client.UpdateExecution(spm_pb2.Json(json=json.dumps(update_)))
 
-
+    def get_execution_status(self, exe_id):
+        return self._base_client.GetExecutionStatus(execution=exe_id)
 
 @contextmanager
 def open_admin_client() -> NumerousAdminClient:
